Eyes Common Python SDK
======================

Applitools Eyes Common SDK For Python


Installation
------------

Install the eyes-common SDK.

::

    pip install eyes-common

Usage
-----

It could be used to create own Applitools SDK
